# helix-platform-api-public-client
_OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_

---

Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api)


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.125
- Package version: 0.0.125
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.eleclink.co.uk](https://www.eleclink.co.uk)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import helix_platform_api_public_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import helix_platform_api_public_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import helix_platform_api_public_client
from helix_platform_api_public_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.helix.eleclink.co.uk
# See configuration.py for a list of all supported configuration parameters.
configuration = helix_platform_api_public_client.Configuration(
    host = "https://api.helix.eleclink.co.uk"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKey
configuration.api_key['ApiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKey'] = 'Bearer'

# Configure Bearer authorization (JWT): AuthToken
configuration = helix_platform_api_public_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with helix_platform_api_public_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = helix_platform_api_public_client.AttachmentApi(api_client)
    file_name = 'file_name_example' # str | 
    file = None # bytearray | 

    try:
        api_response = api_instance.upload_attachment(file_name, file)
        print("The response of AttachmentApi->upload_attachment:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AttachmentApi->upload_attachment: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.helix.eleclink.co.uk*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AttachmentApi* | [**upload_attachment**](docs/AttachmentApi.md#upload_attachment) | **POST** /v1/attachments | 
*AuditLogApi* | [**get_audit_log_payload**](docs/AuditLogApi.md#get_audit_log_payload) | **GET** /v1/audit-logs/{id}/payload | 
*AuditLogApi* | [**get_audit_logs**](docs/AuditLogApi.md#get_audit_logs) | **GET** /v1/audit-logs | 
*DefaultNominationApi* | [**create_default_nomination**](docs/DefaultNominationApi.md#create_default_nomination) | **POST** /v1/default-nominations | 
*DefaultNominationApi* | [**delete_default_nomination**](docs/DefaultNominationApi.md#delete_default_nomination) | **DELETE** /v1/default-nominations/{id} | 
*DefaultNominationApi* | [**get_default_nomination**](docs/DefaultNominationApi.md#get_default_nomination) | **GET** /v1/default-nominations/{id} | 
*DefaultNominationApi* | [**get_default_nomination_options**](docs/DefaultNominationApi.md#get_default_nomination_options) | **GET** /v1/default-nominations/options | 
*DefaultNominationApi* | [**get_default_nominations**](docs/DefaultNominationApi.md#get_default_nominations) | **GET** /v1/default-nominations | 
*DefaultNominationApi* | [**update_default_nomination**](docs/DefaultNominationApi.md#update_default_nomination) | **PUT** /v1/default-nominations/{id} | 
*ManualFileUploadApi* | [**upload_nominations**](docs/ManualFileUploadApi.md#upload_nominations) | **POST** /v1/manual-file-upload/nominations | 
*MessagesApi* | [**get_participant_messages**](docs/MessagesApi.md#get_participant_messages) | **GET** /v1/messages/participant | 
*MessagesApi* | [**get_participant_unread_messages**](docs/MessagesApi.md#get_participant_unread_messages) | **GET** /v1/messages/participant/unread | 
*MessagesApi* | [**get_system_messages**](docs/MessagesApi.md#get_system_messages) | **GET** /v1/messages/system | 
*MetadataApi* | [**get_version**](docs/MetadataApi.md#get_version) | **GET** /v1/public/version | 
*NominationApi* | [**get_aggregated_nomination_options**](docs/NominationApi.md#get_aggregated_nomination_options) | **GET** /v1/nominations/aggregated/options | 
*NominationApi* | [**get_aggregated_nominations**](docs/NominationApi.md#get_aggregated_nominations) | **GET** /v1/nominations/aggregated | 
*NominationApi* | [**get_aggregated_pre_nomination_options**](docs/NominationApi.md#get_aggregated_pre_nomination_options) | **GET** /v1/nominations/aggregated/options/pre-nominations | 
*NominationApi* | [**get_nomination_options**](docs/NominationApi.md#get_nomination_options) | **GET** /v1/nominations/options | 
*NominationApi* | [**get_nominations**](docs/NominationApi.md#get_nominations) | **GET** /v1/nominations | 
*NominationApi* | [**submit_nominations**](docs/NominationApi.md#submit_nominations) | **PUT** /v1/nominations | 
*NominationGateApi* | [**get_nomination_gates_overview**](docs/NominationGateApi.md#get_nomination_gates_overview) | **GET** /v1/nomination-gates/overview | 
*OrganisationApi* | [**get_organisation**](docs/OrganisationApi.md#get_organisation) | **GET** /v1/organisations/{id} | 
*OrganisationApi* | [**get_participant_names**](docs/OrganisationApi.md#get_participant_names) | **GET** /v1/organisations/participant-names | 
*OrganisationApi* | [**get_participant_organisation**](docs/OrganisationApi.md#get_participant_organisation) | **GET** /v1/organisations/participant/{id} | 
*ParticipantDashboardApi* | [**get_participant_dashboard_default_nominations**](docs/ParticipantDashboardApi.md#get_participant_dashboard_default_nominations) | **GET** /v1/participant-dashboard/default-nominations | 
*ParticipantDashboardApi* | [**get_participant_dashboard_interconnector_capacity**](docs/ParticipantDashboardApi.md#get_participant_dashboard_interconnector_capacity) | **GET** /v1/participant-dashboard/interconnector-capacity | 
*ParticipantDashboardApi* | [**get_participant_dashboard_interconnector_capacity_graph**](docs/ParticipantDashboardApi.md#get_participant_dashboard_interconnector_capacity_graph) | **GET** /v1/participant-dashboard/interconnector-capacity-graph | 
*ParticipantDashboardApi* | [**get_participant_dashboard_messages**](docs/ParticipantDashboardApi.md#get_participant_dashboard_messages) | **GET** /v1/participant-dashboard/messages | 
*ParticipantDashboardApi* | [**get_participant_dashboard_netted_nominations**](docs/ParticipantDashboardApi.md#get_participant_dashboard_netted_nominations) | **GET** /v1/participant-dashboard/netted-nominations | 
*ParticipantDashboardApi* | [**get_participant_dashboard_next_nomination_gates**](docs/ParticipantDashboardApi.md#get_participant_dashboard_next_nomination_gates) | **GET** /v1/participant-dashboard/next-nomination-gates | 
*ParticipantDashboardApi* | [**get_participant_dashboard_nomination_options**](docs/ParticipantDashboardApi.md#get_participant_dashboard_nomination_options) | **GET** /v1/participant-dashboard/nominations/options | 
*ParticipantDashboardApi* | [**get_participant_dashboard_transmission_rights_and_nominations**](docs/ParticipantDashboardApi.md#get_participant_dashboard_transmission_rights_and_nominations) | **GET** /v1/participant-dashboard/transmission-rights-and-nominations | 
*ParticipantDashboardApi* | [**get_participant_dashboard_transmission_rights_and_nominations_graph**](docs/ParticipantDashboardApi.md#get_participant_dashboard_transmission_rights_and_nominations_graph) | **GET** /v1/participant-dashboard/transmission-rights-and-nominations-graph | 
*ParticipantDashboardApi* | [**submit_participant_dashboard_nominations**](docs/ParticipantDashboardApi.md#submit_participant_dashboard_nominations) | **PUT** /v1/participant-dashboard/nominations | 
*ParticipantOverviewApi* | [**get_participant_overview**](docs/ParticipantOverviewApi.md#get_participant_overview) | **GET** /v1/participant-overview | 
*ProfileApi* | [**create_api_key**](docs/ProfileApi.md#create_api_key) | **POST** /v1/profile/api-keys | 
*ProfileApi* | [**delete_api_key**](docs/ProfileApi.md#delete_api_key) | **DELETE** /v1/profile/api-keys/{id} | 
*ProfileApi* | [**get_api_keys**](docs/ProfileApi.md#get_api_keys) | **GET** /v1/profile/api-keys | 
*ProfileApi* | [**get_preferences**](docs/ProfileApi.md#get_preferences) | **GET** /v1/profile/preferences | 
*ProfileApi* | [**get_profile**](docs/ProfileApi.md#get_profile) | **GET** /v1/profile | 
*ProfileApi* | [**get_profile_details**](docs/ProfileApi.md#get_profile_details) | **GET** /v1/profile/details | 
*ProfileApi* | [**get_zendesk_chat_token**](docs/ProfileApi.md#get_zendesk_chat_token) | **GET** /v1/profile/zendesk-chat-token | 
*ProfileApi* | [**update_preferences**](docs/ProfileApi.md#update_preferences) | **PUT** /v1/profile/preferences | 
*ProfileApi* | [**update_profile_details**](docs/ProfileApi.md#update_profile_details) | **PUT** /v1/profile/details | 
*PublicOverviewApi* | [**get_public_platform_overview**](docs/PublicOverviewApi.md#get_public_platform_overview) | **GET** /v1/public/platform-overview | 
*ReportingApi* | [**get_organisations_audit_logs_report**](docs/ReportingApi.md#get_organisations_audit_logs_report) | **GET** /v1/reporting/organisations/audit-logs | 
*ReportingApi* | [**get_organisations_users_report**](docs/ReportingApi.md#get_organisations_users_report) | **GET** /v1/reporting/organisations/users | 
*ReportingApi* | [**get_outages_curtailment_report**](docs/ReportingApi.md#get_outages_curtailment_report) | **GET** /v1/reporting/outages/curtailment | 
*ReportingApi* | [**get_trs_and_nominations_overview_report**](docs/ReportingApi.md#get_trs_and_nominations_overview_report) | **GET** /v1/reporting/trs-and-nominations/overview | 
*ReportingApi* | [**get_trs_and_nominations_proof_report**](docs/ReportingApi.md#get_trs_and_nominations_proof_report) | **GET** /v1/reporting/trs-and-nominations/proof | 
*TransmissionRightApi* | [**get_transmission_rights_overview**](docs/TransmissionRightApi.md#get_transmission_rights_overview) | **GET** /v1/transmission-rights/overview | 
*UserApi* | [**bulk_invite_users**](docs/UserApi.md#bulk_invite_users) | **POST** /v1/users/bulk-invite | 
*UserApi* | [**get_user**](docs/UserApi.md#get_user) | **GET** /v1/users/{id} | 
*UserApi* | [**get_users**](docs/UserApi.md#get_users) | **GET** /v1/users | 
*UserApi* | [**invite_user**](docs/UserApi.md#invite_user) | **POST** /v1/users/invite | 
*UserApi* | [**resend_user_invite**](docs/UserApi.md#resend_user_invite) | **PUT** /v1/users/{id}/resend-invite | 
*UserApi* | [**reset_user_second_auth_factor**](docs/UserApi.md#reset_user_second_auth_factor) | **PUT** /v1/users/{id}/reset-second-auth-factor | 
*UserApi* | [**revoke_user_invite**](docs/UserApi.md#revoke_user_invite) | **PUT** /v1/users/{id}/revoke-invite | 
*UserApi* | [**suspend_user**](docs/UserApi.md#suspend_user) | **PUT** /v1/users/{id}/suspend | 
*UserApi* | [**unsuspend_user**](docs/UserApi.md#unsuspend_user) | **PUT** /v1/users/{id}/unsuspend | 
*UserApi* | [**update_user**](docs/UserApi.md#update_user) | **PUT** /v1/users/{id} | 


## Documentation For Models

 - [AggregatedNominationOptions](docs/AggregatedNominationOptions.md)
 - [AggregatedNominationOptionsNomineeParticipants](docs/AggregatedNominationOptionsNomineeParticipants.md)
 - [AggregatedNominations](docs/AggregatedNominations.md)
 - [AggregatedNominationsValues](docs/AggregatedNominationsValues.md)
 - [AggregatedNominationsValuesMtus](docs/AggregatedNominationsValuesMtus.md)
 - [AggregatedNominationsValuesMtusNettedNominations](docs/AggregatedNominationsValuesMtusNettedNominations.md)
 - [AggregatedNominationsValuesMtusValues](docs/AggregatedNominationsValuesMtusValues.md)
 - [AggregatedPreNominationOptions](docs/AggregatedPreNominationOptions.md)
 - [AggregatedPreNominationOptionsTimescale](docs/AggregatedPreNominationOptionsTimescale.md)
 - [ApiKey](docs/ApiKey.md)
 - [Attachment](docs/Attachment.md)
 - [AuditLog](docs/AuditLog.md)
 - [AuditLogApiKey](docs/AuditLogApiKey.md)
 - [AuditLogBatch](docs/AuditLogBatch.md)
 - [AuditLogDomain](docs/AuditLogDomain.md)
 - [AuditLogPayload](docs/AuditLogPayload.md)
 - [AuditLogSortBy](docs/AuditLogSortBy.md)
 - [AuditLogStatus](docs/AuditLogStatus.md)
 - [AuditLogType](docs/AuditLogType.md)
 - [AuditLogUser](docs/AuditLogUser.md)
 - [AuditLogUserOrganisation](docs/AuditLogUserOrganisation.md)
 - [BorderDirection](docs/BorderDirection.md)
 - [BorderDirectionWithBoth](docs/BorderDirectionWithBoth.md)
 - [BorderDirectionWithBothAndNone](docs/BorderDirectionWithBothAndNone.md)
 - [BulkInviteOrganisationUsersRequest](docs/BulkInviteOrganisationUsersRequest.md)
 - [BulkInvitedOrganisationUsers](docs/BulkInvitedOrganisationUsers.md)
 - [BusinessProcessContentBlock](docs/BusinessProcessContentBlock.md)
 - [BusinessProcessForkBlock](docs/BusinessProcessForkBlock.md)
 - [BusinessProcessStepAttempt](docs/BusinessProcessStepAttempt.md)
 - [BusinessProcessStepBlock](docs/BusinessProcessStepBlock.md)
 - [BusinessProcessStepLogicType](docs/BusinessProcessStepLogicType.md)
 - [BusinessProcessStepStatus](docs/BusinessProcessStepStatus.md)
 - [BusinessProcessStepType](docs/BusinessProcessStepType.md)
 - [CreateApiKeyRequest](docs/CreateApiKeyRequest.md)
 - [CreateDefaultNominationRequest](docs/CreateDefaultNominationRequest.md)
 - [CreatedApiKey](docs/CreatedApiKey.md)
 - [CreatedDefaultNomination](docs/CreatedDefaultNomination.md)
 - [DashboardNextNominationGate](docs/DashboardNextNominationGate.md)
 - [DashboardNextNominationGateWindow](docs/DashboardNextNominationGateWindow.md)
 - [DashboardNextNominationWindowStatus](docs/DashboardNextNominationWindowStatus.md)
 - [DataFlowDirection](docs/DataFlowDirection.md)
 - [DefaultNomination](docs/DefaultNomination.md)
 - [DefaultNominationBatch](docs/DefaultNominationBatch.md)
 - [DefaultNominationDeclarationType](docs/DefaultNominationDeclarationType.md)
 - [DefaultNominationDetails](docs/DefaultNominationDetails.md)
 - [DefaultNominationMtu](docs/DefaultNominationMtu.md)
 - [DefaultNominationOptions](docs/DefaultNominationOptions.md)
 - [DefaultNominationSortBy](docs/DefaultNominationSortBy.md)
 - [DefaultNominationStatus](docs/DefaultNominationStatus.md)
 - [ErrorCode](docs/ErrorCode.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [Interface](docs/Interface.md)
 - [IntraDayNominationGate](docs/IntraDayNominationGate.md)
 - [IntraDayNominationGates](docs/IntraDayNominationGates.md)
 - [IntraDayProductType](docs/IntraDayProductType.md)
 - [InviteOrganisationUserRequest](docs/InviteOrganisationUserRequest.md)
 - [InvitedOrganisationUser](docs/InvitedOrganisationUser.md)
 - [LongTermOrDayAheadNominationGate](docs/LongTermOrDayAheadNominationGate.md)
 - [ManualFileUploadRequest](docs/ManualFileUploadRequest.md)
 - [Message](docs/Message.md)
 - [MessageBatch](docs/MessageBatch.md)
 - [MessageCategory](docs/MessageCategory.md)
 - [MessageSender](docs/MessageSender.md)
 - [MessageSeverity](docs/MessageSeverity.md)
 - [MessageSortBy](docs/MessageSortBy.md)
 - [MessageType](docs/MessageType.md)
 - [MtuPeriod](docs/MtuPeriod.md)
 - [MtuSize](docs/MtuSize.md)
 - [MtuSizePerTimescale](docs/MtuSizePerTimescale.md)
 - [NestedError](docs/NestedError.md)
 - [NominationCapacityResolution](docs/NominationCapacityResolution.md)
 - [NominationGateStatus](docs/NominationGateStatus.md)
 - [NominationGatesOverviewResponse](docs/NominationGatesOverviewResponse.md)
 - [NotificationPreference](docs/NotificationPreference.md)
 - [NotificationPreferenceWithSms](docs/NotificationPreferenceWithSms.md)
 - [Organisation](docs/Organisation.md)
 - [OrganisationAuthMethod](docs/OrganisationAuthMethod.md)
 - [OrganisationContact](docs/OrganisationContact.md)
 - [OrganisationContactInformation](docs/OrganisationContactInformation.md)
 - [OrganisationFileSettings](docs/OrganisationFileSettings.md)
 - [OrganisationMarketSettings](docs/OrganisationMarketSettings.md)
 - [OrganisationMarketSettingsFrNominationSettings](docs/OrganisationMarketSettingsFrNominationSettings.md)
 - [OrganisationMarketSettingsGbNominationSettings](docs/OrganisationMarketSettingsGbNominationSettings.md)
 - [OrganisationStatus](docs/OrganisationStatus.md)
 - [OrganisationType](docs/OrganisationType.md)
 - [OrganisationUser](docs/OrganisationUser.md)
 - [OrganisationUserBatch](docs/OrganisationUserBatch.md)
 - [OrganisationUserSortBy](docs/OrganisationUserSortBy.md)
 - [Participant](docs/Participant.md)
 - [ParticipantDashboardDefaultNominationsData](docs/ParticipantDashboardDefaultNominationsData.md)
 - [ParticipantDashboardInterconnectorCapacityData](docs/ParticipantDashboardInterconnectorCapacityData.md)
 - [ParticipantDashboardInterconnectorCapacityDataMtus](docs/ParticipantDashboardInterconnectorCapacityDataMtus.md)
 - [ParticipantDashboardInterconnectorCapacityDataMtusValues](docs/ParticipantDashboardInterconnectorCapacityDataMtusValues.md)
 - [ParticipantDashboardInterconnectorCapacityDataMtusValuesData](docs/ParticipantDashboardInterconnectorCapacityDataMtusValuesData.md)
 - [ParticipantDashboardInterconnectorCapacityGraphData](docs/ParticipantDashboardInterconnectorCapacityGraphData.md)
 - [ParticipantDashboardInterconnectorCapacityGraphDataMtus](docs/ParticipantDashboardInterconnectorCapacityGraphDataMtus.md)
 - [ParticipantDashboardInterconnectorCapacityGraphDataMtusNettedNominations](docs/ParticipantDashboardInterconnectorCapacityGraphDataMtusNettedNominations.md)
 - [ParticipantDashboardInterconnectorCapacityGraphDataMtusValues](docs/ParticipantDashboardInterconnectorCapacityGraphDataMtusValues.md)
 - [ParticipantDashboardMessages](docs/ParticipantDashboardMessages.md)
 - [ParticipantDashboardNettedNominationsData](docs/ParticipantDashboardNettedNominationsData.md)
 - [ParticipantDashboardNettedNominationsDataMtus](docs/ParticipantDashboardNettedNominationsDataMtus.md)
 - [ParticipantDashboardNettedNominationsDataMtusAggregatedNominations](docs/ParticipantDashboardNettedNominationsDataMtusAggregatedNominations.md)
 - [ParticipantDashboardNettedNominationsDataMtusNettedNominations](docs/ParticipantDashboardNettedNominationsDataMtusNettedNominations.md)
 - [ParticipantDashboardNextNominationGates](docs/ParticipantDashboardNextNominationGates.md)
 - [ParticipantDashboardNominationOptions](docs/ParticipantDashboardNominationOptions.md)
 - [ParticipantDashboardNominationOptionsTimescale](docs/ParticipantDashboardNominationOptionsTimescale.md)
 - [ParticipantDashboardTransmissionRightsAndNominationsData](docs/ParticipantDashboardTransmissionRightsAndNominationsData.md)
 - [ParticipantDashboardTransmissionRightsAndNominationsDataMtus](docs/ParticipantDashboardTransmissionRightsAndNominationsDataMtus.md)
 - [ParticipantDashboardTransmissionRightsAndNominationsDataMtusValues](docs/ParticipantDashboardTransmissionRightsAndNominationsDataMtusValues.md)
 - [ParticipantDashboardTransmissionRightsAndNominationsGraphData](docs/ParticipantDashboardTransmissionRightsAndNominationsGraphData.md)
 - [ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtus](docs/ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtus.md)
 - [ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtusValues](docs/ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtusValues.md)
 - [ParticipantOrganisationDetails](docs/ParticipantOrganisationDetails.md)
 - [ParticipantOverviewData](docs/ParticipantOverviewData.md)
 - [ParticipantOverviewDataContactInformation](docs/ParticipantOverviewDataContactInformation.md)
 - [ParticipantOverviewDataOrganisationMembers](docs/ParticipantOverviewDataOrganisationMembers.md)
 - [Permission](docs/Permission.md)
 - [PlatformAppearance](docs/PlatformAppearance.md)
 - [Profile](docs/Profile.md)
 - [ProfileDetails](docs/ProfileDetails.md)
 - [ProfileUser](docs/ProfileUser.md)
 - [ProfileUserOrganisation](docs/ProfileUserOrganisation.md)
 - [PublicPlatformOverviewResponse](docs/PublicPlatformOverviewResponse.md)
 - [PublicPlatformOverviewResponseMtus](docs/PublicPlatformOverviewResponseMtus.md)
 - [PublicPlatformOverviewResponseMtusValues](docs/PublicPlatformOverviewResponseMtusValues.md)
 - [SubmitNominationsMtu](docs/SubmitNominationsMtu.md)
 - [SubmitTimescaleNominationsRequest](docs/SubmitTimescaleNominationsRequest.md)
 - [SystemMessageCategory](docs/SystemMessageCategory.md)
 - [Timescale](docs/Timescale.md)
 - [TimescaleLongTermOrDayAhead](docs/TimescaleLongTermOrDayAhead.md)
 - [TimescaleNominationMtuStatus](docs/TimescaleNominationMtuStatus.md)
 - [TimescaleNominationOptions](docs/TimescaleNominationOptions.md)
 - [TimescaleNominationOptionsWindowTiming](docs/TimescaleNominationOptionsWindowTiming.md)
 - [TimescaleNominationStatus](docs/TimescaleNominationStatus.md)
 - [TimescaleNominationType](docs/TimescaleNominationType.md)
 - [TimescaleNominationWindowStatus](docs/TimescaleNominationWindowStatus.md)
 - [TimescaleNominations](docs/TimescaleNominations.md)
 - [TimescaleNominationsMtus](docs/TimescaleNominationsMtus.md)
 - [TimescaleNominationsMtusCurrentNomination](docs/TimescaleNominationsMtusCurrentNomination.md)
 - [TransmissionRightsOverview](docs/TransmissionRightsOverview.md)
 - [TransmissionRightsOverviewMtus](docs/TransmissionRightsOverviewMtus.md)
 - [TransmissionRightsOverviewMtusValues](docs/TransmissionRightsOverviewMtusValues.md)
 - [TransmissionRightsOverviewMtusValuesTimescales](docs/TransmissionRightsOverviewMtusValuesTimescales.md)
 - [UnreadMessagesResponse](docs/UnreadMessagesResponse.md)
 - [UpdateDefaultNominationRequest](docs/UpdateDefaultNominationRequest.md)
 - [UpdateProfileDetailsRequest](docs/UpdateProfileDetailsRequest.md)
 - [UpdateUserRequest](docs/UpdateUserRequest.md)
 - [User](docs/User.md)
 - [UserOrganisation](docs/UserOrganisation.md)
 - [UserPreferences](docs/UserPreferences.md)
 - [UserPreferencesGeneralNotifications](docs/UserPreferencesGeneralNotifications.md)
 - [UserRole](docs/UserRole.md)
 - [UserStatus](docs/UserStatus.md)
 - [Version](docs/Version.md)
 - [ZendeskChatTokenResponse](docs/ZendeskChatTokenResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKey"></a>
### ApiKey

- **Type**: API key
- **API key parameter name**: X-API-Key
- **Location**: HTTP header

<a id="AuthToken"></a>
### AuthToken

- **Type**: Bearer authentication (JWT)


## Author

team.eleclink@eleclink.co.uk


